@@ -31,6 +31,7 @@ import sys
 import traceback
 from collections.abc import Collection, Mapping, MutableMapping, Sequence
 from concurrent.futures import ProcessPoolExecutor
+from functools import cache
 from typing import TYPE_CHECKING, Any
 
 from celery import Celery, Task, states as celery_states
@@ -41,11 +42,9 @@ from sqlalchemy import select
 
 import airflow.settings as settings
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
 from airflow.executors.base_executor import BaseExecutor
 from airflow.providers.celery.version_compat import AIRFLOW_V_3_0_PLUS
-from airflow.providers.common.compat.sdk import AirflowTaskTimeout, timeout
-from airflow.stats import Stats
+from airflow.providers.common.compat.sdk import AirflowException, AirflowTaskTimeout, Stats, timeout
 from airflow.utils.log.logging_mixin import LoggingMixin
 from airflow.utils.net import get_hostname
 from airflow.utils.providers_configuration_loader import providers_configuration_loaded
@@ -84,24 +83,24 @@ OPERATION_TIMEOUT = conf.getfloat("celery", "operation_timeout")
 # Make it constant for unit test.
 CELERY_FETCH_ERR_MSG_HEADER = "Error fetching Celery task state"
 
-celery_configuration = None
+
+@cache
+def get_celery_configuration() -> dict[str, Any]:
+    """Get the Celery configuration dictionary."""
+    if conf.has_option("celery", "celery_config_options"):
+        return conf.getimport("celery", "celery_config_options")
+
+    from airflow.providers.celery.executors.default_celery import DEFAULT_CELERY_CONFIG
+
+    return DEFAULT_CELERY_CONFIG
 
 
 @providers_configuration_loaded
 def _get_celery_app() -> Celery:
     """Init providers before importing the configuration, so the _SECRET and _CMD options work."""
-    global celery_configuration
-
-    if conf.has_option("celery", "celery_config_options"):
-        celery_configuration = conf.getimport("celery", "celery_config_options")
-    else:
-        from airflow.providers.celery.executors.default_celery import DEFAULT_CELERY_CONFIG
-
-        celery_configuration = DEFAULT_CELERY_CONFIG
-
     celery_app_name = conf.get("celery", "CELERY_APP_NAME")
 
-    return Celery(celery_app_name, config_source=celery_configuration)
+    return Celery(celery_app_name, config_source=get_celery_configuration())
 
 
 app = _get_celery_app()
