@@ -40,11 +40,11 @@ from kubernetes.client import models as k8s
 from uuid6 import uuid7
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException, AirflowTaskTimeout
 from airflow.executors import workloads
 from airflow.models.dag import DAG
 from airflow.models.taskinstance import TaskInstance
 from airflow.models.taskinstancekey import TaskInstanceKey
+from airflow.providers.common.compat.sdk import AirflowException, AirflowTaskTimeout
 from airflow.providers.standard.operators.bash import BashOperator
 from airflow.utils.state import State
 
@@ -79,7 +79,7 @@ def _prepare_app(broker_url=None, execute=None):
         execute_name = "execute_command"
         execute = execute or celery_executor_utils.execute_command.__wrapped__
 
-    test_config = dict(celery_executor_utils.celery_configuration)
+    test_config = dict(celery_executor_utils.get_celery_configuration())
     test_config.update({"broker_url": broker_url})
     test_app = Celery(broker_url, config_source=test_config)
     test_execute = test_app.task(execute)
@@ -168,7 +168,7 @@ class TestCeleryExecutor:
                     run_id="abc",
                     try_number=0,
                     priority_weight=1,
-                    queue=celery_executor_utils.celery_configuration["task_default_queue"],
+                    queue=celery_executor_utils.get_celery_configuration()["task_default_queue"],
                     executor_config=executor_config,
                 )
                 keys = [
@@ -312,6 +312,9 @@ class ClassWithCustomAttributes:
     def __eq__(self, other):
         return self.__dict__ == other.__dict__
 
+    def __hash__(self):
+        return hash(self.__dict__)
+
     def __ne__(self, other):
         return not self.__eq__(other)
 
